@@ -9,7 +9,7 @@ from nctoolkit.runthis import run_this, run_cdo, tidy_command
 from nctoolkit.session import nc_safe, session_info, append_safe, remove_safe
 from nctoolkit.show import nc_variables, nc_years, nc_months, nc_times
 from nctoolkit.temp_file import temp_file
-from nctoolkit.utils import cdo_version, version_above
+from nctoolkit.utils import version_above
 
 
 def arithall(self, stat="divc", x=None):
@@ -33,12 +33,61 @@ def operation(self, method="mul", ff=None, var=None):
     This is used by add etc.
     """
 
-    new = False
+    # throw error if there is a problem with var
+    if var is not None:
+        if type(var) is not str:
+            raise TypeError("var supplied is not a string")
+        if var not in nc_variables(ff):
+            raise ValueError("var supplied is not available in the dataset")
 
-    if version_above(cdo_version(), "1.9.9"):
+    new = False
+    # throw error if the file to operate with does not exist
+    if ff is not None:
+        if os.path.exists(ff) is False:
+            raise ValueError(f"{ff} does not exist!")
+
+    if version_above(session_info["cdo"], "1.9.8"):
         new = True
     else:
-        warnings.warn("Use CDO>=1.9.9 for more smarter operations")
+        warnings.warn("Use CDO>=1.9.10 for smarter operations")
+        self.run()
+
+    # grab the method string
+    if new:
+        if method == "mul":
+            nc_str = "Multiplying by a"
+        if method == "sub":
+            nc_operation = "subtraction"
+            nc_str = "Subtracting a"
+        if method == "add":
+            nc_operation = "addition"
+            nc_str = "Adding a"
+        if method == "div":
+            nc_operation = "division"
+            nc_str = "Dividing by a"
+
+    if new:
+        ff_times = nc_times(ff)
+        if len(ff_times) <= 1:
+            op_method = "single"
+            new = False
+            method = method
+        else:
+            if type(ff_times[0]) == str:
+                years = [int(x.split("T")[0].split("-")[0]) for x in ff_times]
+                months = [int(x.split("T")[0].split("-")[1]) for x in ff_times]
+                days = [int(x.split("T")[0].split("-")[2]) for x in ff_times]
+                ff_times_df = pd.DataFrame({"year":years, "month":months, "day":months})
+            else:
+                ff_times_df = (
+                    pd.DataFrame({"time": ff_times})
+                    .assign(
+                        year=lambda x: x.time.dt.year,
+                        month=lambda x: x.time.dt.month,
+                        day=lambda x: x.time.dt.day,
+                    )
+                    .drop(columns="time")
+                )
 
     if new:
 
@@ -51,66 +100,194 @@ def operation(self, method="mul", ff=None, var=None):
         # then this operation will not work without running it first
         self1.run()
 
-        # throw error if the file to operate with does not exist
-        if ff is not None:
-            if os.path.exists(ff) is False:
-                raise ValueError(f"{ff} does not exist!")
+        self_times = []
+        for x in self1:
+            x_times = nc_times(x)
+            if x_times != []:
+                if type(x_times[0]) == str:
+                    years = [int(x.split("T")[0].split("-")[0]) for x in x_times]
+                    months = [int(x.split("T")[0].split("-")[1]) for x in x_times]
+                    days = [int(x.split("T")[0].split("-")[2]) for x in x_times]
+                    df = pd.DataFrame({"year":years, "month":months, "day":months})
+                    self_times.append(df)
+
+                else:
+                    years = [x.year for x in x_times]
+                    months = [x.month for x in x_times]
+                    days = [x.day for x in x_times]
+                    hours = [x.hour for x in x_times]
+                    df = pd.DataFrame(
+                        {"year": years, "month": months, "day": days, "hour": hours}
+                    )
+                    df["path"] = x
+                    self_times.append(df)
+            else:
+                self_times.append(None)
+
+        possible_switch = True
+        for x in self_times:
+            if x is None:
+                possible_switch = False
+
+    method_dict = dict()
+
+    for x in self:
+        method_dict[x] = None
+
+    # figure out if a yearly will do
+    possible_switch = True
+    if new:
+        if ff_times_df.groupby("year").size().max() == 1:
+            for ss in self_times:
+                if set(ss.year) != set([x for x in list(ff_times_df.year)]):
+                    possible_switch = False
+                else:
+                    if method_dict[x] is not None:
+                        method_dict[x] = f"year{method}"
+
+            if possible_switch:
+                method = f"year{method}"
+                new = False
+                warnings.warn(f"{nc_str} yearly time series")
+
+    # now if all of the files have the same number of time steps
+    possible_switch = True
+    if new:
+        for ss in self_times:
+            if len(ff_times_df) != len(ss):
+                possible_switch = False
+            else:
+                if method_dict[x] is not None:
+                    method_dict[x] = method
+
+            if possible_switch:
+                method = method
+                new = False
+                warnings.warn(f"{nc_str}t time series with the same number of time steps")
+
+    # figure out if a single year monthly will do
+    possible_switch = True
+    if new:
+        if ff_times_df.groupby("month").size().max() == 1:
+            for ss in self_times:
+                if set(ss.month) != set([x for x in list(ff_times_df.month)]):
+                    possible_switch = False
+                else:
+                    if method_dict[x] is not None:
+                        method_dict[x] = f"ymon{method}"
+
+            if possible_switch:
+                method = f"ymon{method}"
+                new = False
+                warnings.warn(f"{nc_str} monthly time series")
+
+    # figure out if a single year monthly will do
+    possible_switch = True
+    if new:
+        if ff_times_df.groupby(["month", "year"]).size().max() == 1:
+            for ss in self_times:
+                if (
+                    ss.loc[:, ["month", "year"]]
+                    .drop_duplicates()
+                    .reset_index(drop=True)
+                    .equals(
+                        ff_times_df.loc[:, ["month", "year"]]
+                        .drop_duplicates()
+                        .reset_index(drop=True)
+                    )
+                    == False
+                ):
+                    possible_switch = False
+                else:
+                    if method_dict[x] is not None:
+                        method_dict[x] = f"mon{method}"
+
+            if possible_switch:
+                method = f"mon{method}"
+                new = False
+                warnings.warn(f"{nc_str} multi-year monthly time series")
+
+    if new:
+
+        #'if possible_switch:
 
         ff_times = nc_times(ff)
-        ff_times_df = pd.DataFrame({"time":ff_times}).assign(year = lambda x: x.time.dt.year, month = lambda x: x.time.dt.month, day = lambda x: x.time.dt.day).drop(columns = "time")
-
-        # work out if it's a yearmon method
-
-        op_method = None
-
-        if len(ff_times_df) > 1:
-            if len(ff_times_df) == len(ff_times_df.drop_duplicates()):
-                if len(ff_times_df) > len(ff_times_df.loc[:,["year", "month"]].drop_duplicates()):
-                    if len(ff_times_df) == len(ff_times_df.loc[:,["year", "month", "day"]].drop_duplicates()):
-                        op_method = "yday"
-
-        if len(ff_times_df) > 1:
-            if len(ff_times_df) == len(ff_times_df.drop(columns = "day").drop_duplicates()):
-                if len(set(ff_times_df.year)) > 1:
-                    if len(set(ff_times_df.month)) > 1:
-                        op_method = "yearmon"
-
-        if len(ff_times_df) > 1:
-            if len(ff_times_df) == len(ff_times_df.drop(columns = "day").drop_duplicates()):
-                if len(set(ff_times_df.year)) == 1:
-                    if len(set(ff_times_df.month)) > 1:
-                        op_method = "mon"
-
-        if len(ff_times_df) > 1:
-            if len(ff_times_df) == len(ff_times_df.drop(columns = "day").drop_duplicates()):
-                if len(set(ff_times_df.year)) > 1:
-                    if len(set(ff_times_df.year)) == len(ff_times_df): 
-                        op_method = "year"
-
-        if len(ff_times_df) == 1:
+        if len(ff_times) == 0:
             op_method = "single"
+        else:
+            ff_times_df = (
+                pd.DataFrame({"time": ff_times})
+                .assign(
+                    year=lambda x: x.time.dt.year,
+                    month=lambda x: x.time.dt.month,
+                    day=lambda x: x.time.dt.day,
+                )
+                .drop(columns="time")
+            )
 
+            # work out if it's a yearmon method
 
-        # throw error if there is a problem with var
-        if var is not None:
-            if type(var) is not str:
-                raise TypeError("var supplied is not a string")
-            if var not in nc_variables(ff):
-                raise ValueError("var supplied is not available in the dataset")
+            op_method = None
+
+            # if len(ff_times_df) > 1 and op_method is not None:
+            if len(ff_times_df) > 1:
+                if len(ff_times_df) == len(ff_times_df.drop_duplicates()):
+                    if len(ff_times_df) > len(
+                        ff_times_df.loc[:, ["year", "month"]].drop_duplicates()
+                    ):
+                        if len(ff_times_df) == len(
+                            ff_times_df.loc[
+                                :, ["year", "month", "day"]
+                            ].drop_duplicates()
+                        ):
+                            op_method = "yday"
+
+            # if len(ff_times_df) > 1 and op_method is not None:
+            if len(ff_times_df) > 1:
+                if len(ff_times_df) == len(
+                    ff_times_df.drop(columns="day").drop_duplicates()
+                ):
+                    if len(set(ff_times_df.year)) > 1:
+                        if len(set(ff_times_df.month)) > 1:
+                            op_method = "yearmon"
+
+            # if len(ff_times_df) > 1 and op_method is not None:
+            if len(ff_times_df) > 1:
+                if len(ff_times_df) == len(
+                    ff_times_df.drop(columns="day").drop_duplicates()
+                ):
+                    if len(set(ff_times_df.year)) == 1:
+                        if len(set(ff_times_df.month)) > 1:
+                            op_method = "mon"
+
+            # if len(ff_times_df) > 1 and op_method is not None:
+            if len(ff_times_df) > 1:
+                if len(ff_times_df) == len(
+                    ff_times_df.drop(columns="day").drop_duplicates()
+                ):
+                    if len(set(ff_times_df.year)) > 1:
+                        if len(set(ff_times_df.year)) == len(ff_times_df):
+                            op_method = "year"
+
+            if len(ff_times_df) == 1:
+                op_method = "single"
 
         bad_vars = False
 
-        for x in self1:
-            n_vars = len(nc_variables(ff))
-            x_vars = len(nc_variables(x))
+        if var is None:
+            for x in self1:
+                n_vars = len(nc_variables(ff))
+                x_vars = len(nc_variables(x))
 
-            if n_vars > x_vars:
-                raise ValueError("Incompatible number of variables in datasets!")
-
-            if n_vars != x_vars:
-                if n_vars > 1:
+                if n_vars > x_vars:
                     raise ValueError("Incompatible number of variables in datasets!")
 
+                if n_vars != x_vars:
+                    if n_vars > 1:
+                        raise ValueError(
+                            "Incompatible number of variables in datasets!"
+                        )
+
         self1.run()
         # leap years are tricky....
 
@@ -142,14 +319,30 @@ def operation(self, method="mul", ff=None, var=None):
             for file in self1:
                 file_times = nc_times(file)
                 if len([x for x in file_times if "-02-29" in str(x)]) > 0:
-                    raise ValueError("Dataset contains leap years, so the operation is ambiguous. Consider removing 29th February!")
-                df_times = pd.DataFrame({"year":[x.year for x in file_times], "month":[x.month for x in file_times], "day": [x.day for x in file_times]}).drop_duplicates()
+                    raise ValueError(
+                        "Dataset contains leap years, so the operation is ambiguous. Consider removing 29th February!"
+                    )
+                df_times = pd.DataFrame(
+                    {
+                        "year": [x.year for x in file_times],
+                        "month": [x.month for x in file_times],
+                        "day": [x.day for x in file_times],
+                    }
+                ).drop_duplicates()
 
                 for yy in df_times.year:
-                    if len(df_times.query("year == @yy").merge(ff_times_df)) != len(ff_times_df):
-                        raise ValueError(f"Time steps for the datasets/files are not compatible for the {nc_operation} method")
-                    if len(df_times.query("year == @yy").merge(ff_times_df)) != len(df_times.query("year == @yy")):
-                        raise ValueError(f"Time steps for the datasets/files are not compatible for the {nc_operation} method")
+                    if len(df_times.query("year == @yy").merge(ff_times_df)) != len(
+                        ff_times_df
+                    ):
+                        raise ValueError(
+                            f"Time steps for the datasets/files are not compatible for the {nc_operation} method"
+                        )
+                    if len(df_times.query("year == @yy").merge(ff_times_df)) != len(
+                        df_times.query("year == @yy")
+                    ):
+                        raise ValueError(
+                            f"Time steps for the datasets/files are not compatible for the {nc_operation} method"
+                        )
 
         if op_method == "year":
             for file in self1:
@@ -172,23 +365,33 @@ def operation(self, method="mul", ff=None, var=None):
         new_commands = []
         new_files = []
 
+        orig_op_method = op_method
+
         for x in self1:
 
+            op_method = orig_op_method
+
+            if len(nc_times(x)) == len(ff_times):
+                op_method = "single"
+
             run = False
 
             if op_method == "single" and run == False:
                 run = True
-                if len(ff_times_df) == 1:
-                    warnings.warn(f"{nc_str} single time step time series")
+                if len(ff_times) > 0:
+                    if len(ff_times_df) == 1:
+                        warnings.warn(f"{nc_str} single time step time series")
 
-                if len(ff_times_df) == len(nc_times(x)):
+                    if len(ff_times_df) == len(nc_times(x)):
 
-                    warnings.warn(f"{nc_str} time series with the same number of time steps")
+                        warnings.warn(
+                            f"{nc_str} time series with the same number of time steps"
+                        )
 
-                if len(nc_times(x)) < len(nc_times(ff)):
-                    warnings.warn(
-                        f"Warning: Files do not have the same number of time steps. Only matching time steps used by {nc_operation}."
-                    )
+                    if len(nc_times(x)) < len(nc_times(ff)):
+                        warnings.warn(
+                            f"Warning: Files do not have the same number of time steps. Only matching time steps used by {nc_operation}."
+                        )
                 if var is not None:
                     cdo_command = f"cdo -{method} {x} -selname,{var} {ff}"
                 else:
@@ -228,26 +431,26 @@ def operation(self, method="mul", ff=None, var=None):
             ## monthly time series
 
             if op_method == "mon" and run == False:
-               run = True
+                run = True
 
-               if bad_vars:
-                   raise ValueError(
-                       "Datasets/files do not have the same number of variables!"
-                   )
-               if var is not None:
-                   cdo_command = f"cdo -ymon{method} {x} -selname,{var} {ff}"
-               else:
-                   cdo_command = f"cdo -ymon{method} {x} {ff}"
+                if bad_vars:
+                    raise ValueError(
+                        "Datasets/files do not have the same number of variables!"
+                    )
+                if var is not None:
+                    cdo_command = f"cdo -ymon{method} {x} -selname,{var} {ff}"
+                else:
+                    cdo_command = f"cdo -ymon{method} {x} {ff}"
 
-               target = temp_file(".nc")
-               cdo_command = f"{cdo_command} {target}"
-               target = run_cdo(cdo_command, target, precision=self1._precision)
-               new_files.append(target)
-               new_commands.append(cdo_command)
-               warnings.warn(f"{nc_str} monthly time series")
+                target = temp_file(".nc")
+                cdo_command = f"{cdo_command} {target}"
+                target = run_cdo(cdo_command, target, precision=self1._precision)
+                new_files.append(target)
+                new_commands.append(cdo_command)
+                warnings.warn(f"{nc_str} monthly time series")
             ## yearly time series
 
-            if op_method == "year" and run == False:  
+            if op_method == "year" and run == False:
                 run = True
                 if var is not None:
                     cdo_command = f"cdo -year{method} {x} -selname,{var} {ff}"
@@ -260,7 +463,6 @@ def operation(self, method="mul", ff=None, var=None):
                 new_commands.append(cdo_command)
                 warnings.warn(f"{nc_str} yearly time series")
 
-
             if len(nc_years(ff)) == 1 and run is False:
                 if (len(nc_times(x)) / len(nc_years(x))) == len(nc_times(ff)):
                     run = True
@@ -274,7 +476,9 @@ def operation(self, method="mul", ff=None, var=None):
 
                         if len(ff_times_df) == len(nc_times(x)):
 
-                            warnings.warn(f"{nc_str} time series with the same number of time steps")
+                            warnings.warn(
+                                f"{nc_str} time series with the same number of time steps"
+                            )
 
                         if len(nc_times(x)) < len(nc_times(ff)):
                             warnings.warn(
@@ -287,7 +491,9 @@ def operation(self, method="mul", ff=None, var=None):
 
                         target = temp_file(".nc")
                         cdo_command = f"{cdo_command} {target}"
-                        target = run_cdo(cdo_command, target, precision=self1._precision)
+                        target = run_cdo(
+                            cdo_command, target, precision=self1._precision
+                        )
                         new_files.append(target)
                         new_commands.append(cdo_command)
                     else:
@@ -297,11 +503,12 @@ def operation(self, method="mul", ff=None, var=None):
                             cdo_command = f"cdo -yday{method} {x} {ff}"
                         target = temp_file(".nc")
                         cdo_command = f"{cdo_command} {target}"
-                        target = run_cdo(cdo_command, target, precision=self1._precision)
+                        target = run_cdo(
+                            cdo_command, target, precision=self1._precision
+                        )
                         new_files.append(target)
                         new_commands.append(cdo_command)
 
-
             if run is False:
                 if len(nc_times(x)) < len(nc_times(ff)):
                     warnings.warn(
@@ -337,8 +544,8 @@ def operation(self, method="mul", ff=None, var=None):
 
             self1.current = new_files
 
-            for ff in new_files:
-                remove_safe(ff)
+            for ff1 in new_files:
+                remove_safe(ff1)
             self1._hold_history = copy.deepcopy(self1.history)
 
             if merge_names:
@@ -416,8 +623,8 @@ def operation(self, method="mul", ff=None, var=None):
 
             self.current = new_files
 
-            for ff in new_files:
-                remove_safe(ff)
+            for ff1 in new_files:
+                remove_safe(ff1)
             self._hold_history = copy.deepcopy(self.history)
             cleanup()
 
@@ -544,7 +751,7 @@ def subtract(self, x=None, var=None):
 def add(self, x=None, var=None):
     """
     Add to a dataset
-    This will add a constant, another dataset or a netCDF file to the dataset. 
+    This will add a constant, another dataset or a netCDF file to the dataset.
     nctoolkit will automatically determine the appropriate comparison required.
 
      Parameters
