@@ -389,7 +389,7 @@ def from_xarray(ds):
     return d
 
 
-def open_data(x=[], checks=False, **kwargs):
+def open_data(x=[], checks=True, **kwargs):
     """
     Read netCDF data as a DataSet object
 
@@ -402,7 +402,7 @@ def open_data(x=[], checks=False, **kwargs):
         By default an empty dataset is created, ie. using open_data() will create an empty
         dataset that can then be expanded using append.
     checks: boolean
-        Do you want basic checks to ensure cdo can read files?
+        Do you want basic checks to ensure cdo can read files? Default to True
     **kwargs: kwargs
         Optional arguments for internal use by open_thredds and open_url.
 
@@ -559,6 +559,9 @@ def open_data(x=[], checks=False, **kwargs):
                 mes = re.sub(" +", " ", mes)
                 raise ValueError(mes)
 
+            append_safe(x)
+            append_protected(x)
+
         else:
             append_safe(x)
             append_protected(x)
@@ -653,10 +656,16 @@ def open_data(x=[], checks=False, **kwargs):
     d = DataSet(x)
     d._thredds = thredds
 
-    if len(d) == 1:
-        df = d.contents.reset_index(drop=True).query("'I' in data_type")
-        if len(df) > 0:
-            check = ",".join(list(df.variable))
+    if (len(d) == 1) and checks and (thredds is False):
+
+        list1 = d.contents.reset_index(drop=True).data_type
+        positions = [ind for ind, x in enumerate(list1) if x.startswith("I")]
+        if len(positions):
+            bad = list(d.contents.reset_index(drop=True).variable[positions])
+
+        # df = d.contents.reset_index(drop=True).query("'I' in data_type")
+        if len(positions) > 0:
+            check = ",".join(bad)
             if "," in check:
                 warnings.warn(
                     message=f"The variable(s) {check} have integer data type. Consider setting data type to float 'F64' or 'F32' using set_precision."
@@ -1025,6 +1034,36 @@ class DataSet(object):
         result = result + "Largest file: " + largest_file + " has size " + max_size
         return result
 
+    @property
+    def calendar(self):
+        """
+        List calendars of dataset files
+        """
+
+        # return None
+
+        cals = []
+        for ff in self:
+            ds = Dataset(ff)
+            for x in [x for x in ds.variables.keys() if "time" in x]:
+                y = ds.variables[x]
+                try:
+                    cal = y.getncattr("calendar")
+                except:
+                    cal = None
+                if cal is not None:
+                    break
+            if cal is None:
+                raise ValueError("Unable to parse the calendars")
+
+            cals.append(pd.DataFrame({"file": ff, "calendar": [cal]}))
+
+        cals = pd.concat(cals).reset_index(drop=True)
+
+        if len(set(cals.calendar)) == 1:
+            return cals.calendar[0]
+        return cals
+
     @property
     def variables(self):
         """
@@ -1241,7 +1280,7 @@ class DataSet(object):
 
             times = []
 
-            ds = Dataset(ff)
+            ds = xr.open_dataset(ff, decode_times = False)
             time_name = [x for x in ds.variables if "time" in x]
 
             # get time name
@@ -1302,97 +1341,6 @@ class DataSet(object):
         else:
             return pd.concat(list_contents).set_index("file")
 
-    @property
-    def variables_detailed(self):
-        """
-        Detailed list of variables contained in a dataset.
-        This will only display the variables in the first file of an ensemble.
-        """
-
-        if len(self) > 1:
-            return (
-                "This DataSet object is a mult-file dataset. Please inspect individual"
-                "files using nc_variables"
-            )
-
-        cdo_result = subprocess.run(
-            "cdo showname " + self.current[0],
-            shell=True,
-            stdout=subprocess.PIPE,
-            stderr=subprocess.PIPE,
-        )
-        cdo_result = (
-            str(cdo_result.stdout)
-            .replace("b'", "")
-            .replace("\\n", "")
-            .replace("'", "")
-            .strip()
-        )
-        cdo_result = cdo_result.split()
-        dataset = Dataset(self.current[0])
-
-        longs = None
-        units = None
-        longs = []
-        for x in cdo_result:
-            try:
-                longs.append(dataset.variables[x].long_name)
-            except:
-                longs.append(None)
-        # longs = [dataset.variables[x].long_name for x in cdo_result]
-        units = []
-        for x in cdo_result:
-            try:
-                units.append(dataset.variables[x].units)
-            except:
-                units.append(None)
-        ##units = [dataset.variables[x].units for x in cdo_result]
-
-        if longs is None and units is None:
-            return cdo_result
-
-        out = subprocess.run(
-            "cdo sinfon " + self.current[0],
-            shell=True,
-            stdout=subprocess.PIPE,
-            stderr=subprocess.PIPE,
-        )
-        out = out.stdout.decode("utf-8")
-        out = out.split("\n")
-        out_inc = ["Grid coordinates :" in ff for ff in out]
-        var_det = []
-        i = 1
-        while True:
-            if out_inc[i]:
-                break
-            i += 1
-            var_det.append(out[i - 1])
-
-        var_det = [ff.replace(":", "") for ff in var_det]
-        var_det = [" ".join(ff.split()) for ff in var_det]
-        var_det = [
-            ff.replace("Parameter name", "variable").split(" ") for ff in var_det
-        ]
-        df_vars = var_det[1:]
-        labels = var_det[0]
-
-        df = pd.DataFrame.from_records(df_vars, columns=labels)
-        df = df.loc[:, ["Levels", "Points", "variable"]]
-        df = df.rename(columns={"Levels": "levels", "Points": "points"})
-
-        df = pd.DataFrame({"variable": cdo_result}).merge(df)
-
-        if longs is not None:
-            df["long_name"] = longs
-        if units is not None:
-            df["units"] = units
-
-        df = df.assign(levels=lambda x: x.levels.astype("int")).assign(
-            points=lambda x: x.points.astype("int")
-        )
-
-        return df
-
     @property
     def start(self):
         """
@@ -1493,6 +1441,8 @@ class DataSet(object):
 
     from nctoolkit.centres import centre
 
+    from nctoolkit.checks import check
+
     from nctoolkit.cleanup import disk_clean
 
     from nctoolkit.compare import compare
@@ -1528,8 +1478,10 @@ class DataSet(object):
     from nctoolkit.fldstat import spatial_min
     from nctoolkit.fldstat import spatial_max
     from nctoolkit.fldstat import spatial_range
+    from nctoolkit.fldstat import spatial_stdev
     from nctoolkit.fldstat import spatial_sum
     from nctoolkit.fldstat import spatial_percentile
+    from nctoolkit.fldstat import spatial_var
 
     from nctoolkit.fldstat import box_mean
     from nctoolkit.fldstat import box_max
