@@ -23,7 +23,7 @@ def reduce_grid(self, mask=None):
         target = mask
 
     if "api.DataSet" in str(type(mask)):
-        target = mask.current
+        target = mask.current[0]
 
     if target is None:
         raise ValueError("No mask supplied")
@@ -33,7 +33,7 @@ def reduce_grid(self, mask=None):
     targeted_mask.cdo_command("-setmisstoc,0")
     targeted_mask.run()
 
-    cdo_command = f"cdo -reducegrid,{targeted_mask.current}"
+    cdo_command = f"cdo -reducegrid,{targeted_mask.current[0]}"
 
     run_this(cdo_command, self, output="ensemble")
     self.run()
