@@ -39,7 +39,7 @@ def to_nc(self, out, zip=True, overwrite=False):
     """
 
     if len(self) == 0:
-        raise ValueError("Failure due to empty dataset!")
+        raise ValueError("You cannot save an empty dataset!")
 
     if os.path.basename(out) != out:
         out_dir = os.path.dirname(out)
@@ -65,6 +65,10 @@ def to_nc(self, out, zip=True, overwrite=False):
     if write is False:
         raise ValueError("You cannot save multiple files!")
 
+    if (os.path.exists(out)) and (overwrite is True):
+        if len(self) > 1:
+            self.run()
+
     # Check if outfile exists and overwrite is set to False
     # This should maybe be a warning, not an error
     if (os.path.exists(out)) and (overwrite is False):
@@ -73,7 +77,9 @@ def to_nc(self, out, zip=True, overwrite=False):
     if len(self.history) == len(self._hold_history):
         if zip:
             cdo_command = f"cdo -z zip_9 copy {ff[0]} {out}"
-            run_cdo(cdo_command, target=out, overwrite=overwrite)
+            run_cdo(
+                cdo_command, target=out, overwrite=overwrite, precision=self._precision
+            )
 
             self.history.append(cdo_command)
             self._hold_history = copy.deepcopy(self.history)
@@ -82,7 +88,9 @@ def to_nc(self, out, zip=True, overwrite=False):
 
         else:
             cdo_command = f"cdo copy {ff[0]} {out}"
-            run_cdo(cdo_command, target=out, overwrite=overwrite)
+            run_cdo(
+                cdo_command, target=out, overwrite=overwrite, precision=self._precision
+            )
             self.history.append(cdo_command)
             self._hold_history = copy.deepcopy(self.history)
 
